==> MediaWikiLanguageExtensionBundle-2012.12.tar.bz2: extensions/cldr/CldrNames/CldrNamesLn.php <==
<?php

$languageNames = array(
'af' => 'afrikansi',
'ak' => 'akan',
'am' => 'liamariki',
'ar' => 'lialabo',
'be' => 'libyelorisí',
'bg' => 'libiligali',
'bn' => 'libengali',
'cs' => 'litshekɛ',
'de' => 'lialemá',
'de-at' => 'lialémani ya Otrish',
'de-ch' => 'lialémani ya Swisi',
'el' => 'ligeleki',
'en' => 'lingɛlɛ́sa',
'en-ca' => 'lingɛlɛ́sa ya Kanadá',
'en-gb' => 'lingɛlɛ́sa ya Ingɛlɛ́tɛlɛ',
'es' => 'lisipanye',
'es-419' => 'lispanyoli ya Ameríka Latína',
'es-es' => 'lispanyoli ya Erópa',
'fa' => 'lipelésanɛ',
'fr' => 'lifalansɛ́',
'fr-ca' => 'lifalansɛ́ ya Kanadá',
'fr-ch' => 'lifalansɛ́ ya Swisi',
'gsw' => 'lialemaniki',
'ha' => 'hausa',
'he' => 'liébeleo',
'hi' => 'lihindi',
'hu' => 'liongili',
'id' => 'lindonezi',
'ig' => 'igbo',
'it' => 'litaliano',
'ja' => 'lizapɔ',
'jv' => 'lizava',
'kg' => 'kikɔ́ngɔ',
'km' => 'likambodza',
'ko' => 'likoreya',
'la' => 'latina',
'ln' => 'lingála',
'lu' => 'kiluba',
'lua' => 'ciluba',
'ms' => 'limalezi',
'my' => 'libilimá',
'ne' => 'linepalɛ',
'nl' => 'lifalamá',
'pa' => 'lipendzabi',
'pl' => 'lipolonɛ',
'pt' => 'lipulutugɛ́si',
'pt-br' => 'lipulutugɛ́si ya Brazil',
'pt-pt' => 'lipulutugɛ́si ya Erópa',
'rm' => 'liromansh',
'ro' => 'liromani',
'ru' => 'lirisí',
'rw' => 'kinyarwanda',
'so' => 'lisomali',
'sv' => 'lisuwedɛ',
'sw' => 'kiswahíli',
'ta' => 'litamuli',
'th' => 'litaye',
'tr' => 'litiliki',
'uk' => 'likrɛni',
'ur' => 'liurdu',
'vi' => 'liviyetinámi',
'yo' => 'yoruba',
'zh' => 'lisinwa',
'zu' => 'zulu',
);

$currencyNames = array(
'AED' => 'Dirihamɛ ya Lémila alabo',
'AOA' => 'Kwanza ya Angóla',
'ARS' => 'Peso y\'Argentina',
'AUD' => 'Dolarɛ ya Ositali',
'BHD' => 'Dinarɛ ya Bahrɛnɛ',
'BIF' => 'Falánga ya Burundi',
'BOB' => 'Boliviano',
'BRL' => 'Real ya Brazil',
'BWP' => 'Pula ya Botswana',
'CAD' => 'Dolarɛ ya Kanadá',
'CDF' => 'Falánga ya Kongó',
'CHF' => 'Falánga ya Swisɛ',
'CLP' => 'Peso ya Shili',
'CNY' => 'Yuanɛ Renminbi ya Sinɛ',
'COP' => 'Peso ya Kolombi',
'CRC' => 'Colon ya Kosta Rika',
'CUP' => 'Peso ya Kuba',
'CVE' => 'Esikudo ya Kapevɛrɛ',
'CZK' => 'Motolé Sheki',
'DJF' => 'Falánga ya Dzibuti',
'DKK' => 'Motolé ya Danemark',
'DOP' => 'Peso Dominikani',
'DZD' => 'Dinarɛ ya Alizeri',
'EGP' => 'Paunɛ ya Ezípitɛ',
'ERN' => 'Nakfa ya Elitlɛ',
'ETB' => 'Birɛ ya Etsiópi',
'EUR' => 'Ɛlɔ́',
'GBP' => 'Paunɛ ya Angɛlɛtɛ́lɛ',
'GHC' => 'Sedi ya Gana',
'GHS' => 'Cedi',
'GMD' => 'Dalasi ya Gambi',
'GNF' => 'Falánga ya Gine',
'GNS' => 'Falánga ya Ginɛ',
'HTG' => 'Gurde',
'INR' => 'Rupi yaÍndɛ',
'ISK' => 'Motolé ya Islandi',
'JPY' => 'Yeni ya Zapɔ',
'KES' => 'Shilingɛ ya Kenya',
'KMF' => 'Falánga ya Komoro',
'LRD' => 'Dolarɛ ya Liberya',
'LSL' => 'Loti ya Lesóto',
'LTL' => 'Litas ya Litwani',
'LVL' => 'Lats ya Letoni',
'LYD' => 'Dinarɛ ya Libí',
'MAD' => 'Dirihame ya Marokɛ',
'MGA' => 'Falánga ya Madagasikarɛ',
'MRO' => 'Ugwiya ya Moritani',
'MUR' => 'Rupi ya Morisi',
'MWK' => 'Kwasha ya Malawi',
'MXN' => 'Peso ya Mexiko',
'MZM' => 'Metikali ya Mozambiki',
'NAD' => 'Dolarɛ ya Namibi',
'NGN' => 'Naira ya Nizerya',
'NOK' => 'Motolé ya Norvej',
'PAB' => 'Balboa',
'PEN' => 'Sol Sika',
'PYG' => 'Guarani',
'RWF' => 'Falánga ya Rwanda',
'SAR' => 'Riyalɛ ya Alabi Sawuditɛ',
'SCR' => 'Rupi ya Sɛshɛlɛ',
'SDG' => 'Dinarɛ ya Sudá',
'SDP' => 'Paunɛ ya Sudá',
'SEK' => 'Motolé ya Swédi',
'SHP' => 'Paunɛ ya Sántu elena',
'SLL' => 'Leonɛ',
'SOS' => 'Shilingɛ ya Somali',
'STD' => 'Dobra ya Sao Tomé mpé Presipe',
'SZL' => 'Lilangeni',
'TND' => 'Dinarɛ ya Tinizi',
'TZS' => 'Shilingɛ ya Tanzani',
'UGX' => 'Shilingɛ ya Uganda',
'USD' => 'Dolarɛ ya Ameriki',
'XAF' => 'Falánga CFA BEAC',
'XOF' => 'Falánga CFA BCEAO',
'ZAR' => 'Randɛ ya Afríka Súdi',
'ZMK' => 'Kwasha ya Zambi',
'ZWD' => 'Dolarɛ ya Zimbabwɛ',
);

$countryNames = array(
'AC' => 'Esenga ya Mbuta o likoló',
'AD' => 'Andorɛ',
'AE' => 'Lɛmila alabo',
'AF' => 'Afiganisitá',
'AG' => 'Antiga mpé Barbuda',
'AI' => 'Angiyɛ',
'AL' => 'Alibani',
'AM' => 'Amɛni',
'AN' => 'Antiyɛ ya Olandɛ',
'AO' => 'Angóla',
'AR' => 'Arizantinɛ',
'AS' => 'Samoa ya Ameriki',
'AT' => 'Otilisi',
'AU' => 'Ositáli',
'AW' => 'Aruba',
'AX' => 'BisangaƐland',
'AZ' => 'Azɛlɛbaizá',
'BA' => 'Bosini mpé Hezegovine',
'BB' => 'Barɛbadɛ',
'BD' => 'Bengalidɛsi',
'BE' => 'Beleziki',
'BF' => 'Bukina Faso',
'BG' => 'Biligari',
'BH' => 'Bahrɛnɛ',
'BI' => 'Burundi',
'BJ' => 'Benɛ',
'BM' => 'Bermuda',
'BN' => 'Brineyi',
'BO' => 'Bolivi',
'BR' => 'Brezílɛ',
'BS' => 'Bahamasɛ',
'BT' => 'Butáni',
'BV' => 'Esenga Buvé',
'BW' => 'Botswana',
'BY' => 'Byelorisi',
'BZ' => 'Belizɛ',
'CA' => 'Kanada',
'CC' => 'Bisanga Kokos',
'CD' => 'Repibiki demokratiki ya Kongó',
'CF' => 'Repibiki ya Afríka ya Káti',
'CG' => 'Kongo',
'CH' => 'Swisɛ',
'CI' => 'Kotídivualɛ',
'CK' => 'Bisanga bya Kookɛ',
'CL' => 'Síli',
'CM' => 'Kamɛrune',
'CN' => 'Sinɛ',
'CO' => 'Kolombi',
'CR' => 'Kositarika',
'CU' => 'Kiba',
'CV' => 'Bisanga bya Kapevɛrɛ',
'CX' => 'Esenga ya Mbótama',
'CY' => 'Sípɛlɛ',
'CZ' => 'Repibiki Tsekɛ',
'DE' => 'Alemani',
'DJ' => 'Dzibuti',
'DK' => 'Danɛmarike',
'DM' => 'Domínike',
'DO' => 'Repibiki ya Domínikɛ',
'DZ' => 'Alizɛri',
'EA' => 'Zewta mpé Melílla',
'EC' => 'Ekwatɛ́lɛ',
'EE' => 'Esitoni',
'EG' => 'Ezípite',
'EH' => 'Sahara ya Limbɛ',
'ER' => 'Elitelɛ',
'ES' => 'Esipanye',
'ET' => 'Etsíopi',
'EU' => 'Lisangá ya Erópa',
'FI' => 'Filandɛ',
'FJ' => 'Fidzi',
'FK' => 'Bisanga bya Maluni',
'FM' => 'Mikronezi',
'FO' => 'Bisanga ya Fɛróa',
'FR' => 'Falánsɛ',
'GA' => 'Gabɔ',
'GB' => 'Angɛlɛtɛ́lɛ',
'GD' => 'Gelenadɛ',
'GE' => 'Zorzi',
'GF' => 'Giyanɛ ya Falánsɛ',
'GH' => 'Gana',
'GI' => 'Zibatalɛ',
'GL' => 'Gowelande',
'GM' => 'Gambi',
'GN' => 'Ginɛ',
'GP' => 'Gwadɛlupɛ',
'GQ' => 'Ginɛ́kwatɛ́lɛ',
'GR' => 'Geleki',
'GT' => 'Gwatémala',
'GU' => 'Gwamɛ',
'GW' => 'Ginɛbisau',
'GY' => 'Giyane',
'HK' => 'Hong Kong',
'HN' => 'Ondurasɛ',
'HR' => 'Krowasi',
'HT' => 'Ayiti',
'HU' => 'Ongili',
'IC' => 'Bisanga bya Kanári',
'ID' => 'Indonezi',
'IE' => 'Irelandɛ',
'IL' => 'Isirayelɛ',
'IM' => 'Esanga ya Man',
'IN' => 'Índɛ',
'IO' => 'Mabelé ya Angɛlɛtɛ́lɛ na mbú ya Indiya',
'IQ' => 'Iraki',
'IR' => 'Irâ',
'IS' => 'Isilandɛ',
'IT' => 'Itali',
'JM' => 'Zamaiki',
'JO' => 'Zɔdani',
'JP' => 'Zapɔ',
'KE' => 'Kenya',
'KG' => 'Kigizisitá',
'KH' => 'Kambodza',
'KI' => 'Kiribati',
'KM' => 'Komorɛ',
'KN' => 'Sántu krístofe mpé Nevɛ̀s',
'KP' => 'Korɛ ya nɔ́rdi',
'KR' => 'Korɛ ya súdi',
'KW' => 'Koweti',
'KY' => 'Bisanga bya Kayíma',
'KZ' => 'Kazakisitá',
'LA' => 'Lawosi',
'LB' => 'Libá',
'LC' => 'Sántu lisi',
'LI' => 'Lishɛteni',
'LK' => 'Sirilanka',
'LR' => 'Libériya',
'LS' => 'Lesoto',
'LT' => 'Litwani',
'LU' => 'Likisambulu',
'LV' => 'Letoni',
'LY' => 'Libí',
'MA' => 'Marokɛ',
'MC' => 'Monako',
'MD' => 'Molidavi',
'MG' => 'Madagasikari',
'MH' => 'Bisanga bya Marishalɛ',
'MK' => 'Masedwanɛ',
'ML' => 'Malí',
'MN' => 'Mongolí',
'MO' => 'Makau',
'MP' => 'Bisanga bya Marianɛ ya nɔ́rdi',
'MQ' => 'Martiniki',
'MR' => 'Moritani',
'MS' => 'Mɔsera',
'MT' => 'Malitɛ',
'MU' => 'Morisɛ',
'MV' => 'Madívɛ',
'MW' => 'Malawi',
'MX' => 'Meksike',
'MY' => 'Malezi',
'MZ' => 'Mozambíki',
'NA' => 'Namibi',
'NC' => 'Kaledoni ya sika',
'NE' => 'Nizɛrɛ',
'NF' => 'Esanga Norfokɛ',
'NG' => 'Nizerya',
'NI' => 'Nikaragwa',
'NL' => 'Olandɛ',
'NO' => 'Norivezɛ',
'NP' => 'Nepálɛ',
'NR' => 'Nauru',
'NU' => 'Nyué',
'NZ' => 'Zelandɛ ya sika',
'OM' => 'Ománɛ',
'PA' => 'Panama',
'PE' => 'Péru',
'PF' => 'Polinezi ya Falánsɛ',
'PG' => 'Papwazi Ginɛ ya sika',
'PH' => 'Filipinɛ',
'PK' => 'Pakisitá',
'PL' => 'Poloni',
'PM' => 'Sántu pététo mpé Mikelɔ',
'PN' => 'Pikairni',
'PR' => 'Pɔtoriko',
'PS' => 'Palɛsine',
'PT' => 'Putúlugɛsi',
'PW' => 'Palau',
'PY' => 'Palagwei',
'QA' => 'Katari',
'RE' => 'Lenyo',
'RO' => 'Romani',
'RU' => 'Risí',
'RW' => 'Rwanda',
'SA' => 'Alabi Sawuditɛ',
'SB' => 'Bisanga Solomɔ',
'SC' => 'Sɛshɛlɛ',
'SD' => 'Sudá',
'SE' => 'Swédɛ',
'SG' => 'Singapurɛ',
'SH' => 'Sántu eleni',
'SI' => 'Siloveni',
'SJ' => 'Svalbard mpé Jan Mayen',
'SK' => 'Silovaki',
'SL' => 'Siera Leonɛ',
'SM' => 'Sántu Marinɛ',
'SN' => 'Senegalɛ',
'SO' => 'Somali',
'SR' => 'Surinamɛ',
'SS' => 'Sudani ya Sidi',
'ST' => 'Sao Tomé mpé Presipɛ',
'SV' => 'Savadɔrɛ',
'SY' => 'Sirí',
'SZ' => 'Swazilandi',
'TC' => 'Bisanga bya Turki mpé Kaiko',
'TD' => 'Tsádi',
'TG' => 'Togo',
'TH' => 'Tailandɛ',
'TJ' => 'Tazikisitá',
'TK' => 'Tokelau',
'TL' => 'Timorɛ ya Moniɛlɛ',
'TM' => 'Tikɛménisitá',
'TN' => 'Tinizi',
'TO' => 'Tonga',
'TR' => 'Tiliki',
'TT' => 'Tinidadɛ mpé Tobago',
'TV' => 'Tuvalu',
'TW' => 'Taiwanin',
'TZ' => 'Tanzani',
'UA' => 'Ikrɛni',
'UG' => 'Uganda',
'US' => 'Ameriki',
'UY' => 'Irigwei',
'UZ' => 'Uzibɛkisitá',
'VA' => 'Vatiká',
'VC' => 'Sántu vesá mpé Gelenadinɛ',
'VE' => 'Venézuela',
'VG' => 'Bisanga bya Vierzi ya Angɛlɛtɛ́lɛ',
'VI' => 'Bisanga bya Vierzi ya Ameriki',
'VN' => 'Viyetinamɛ',
'VU' => 'Vanuatu',
'WF' => 'Walisɛ mpé Futuna',
'WS' => 'Samoa',
'YE' => 'Yemɛnɛ',
'YT' => 'Mayotɛ',
'ZA' => 'Afríka ya Súdi',
'ZM' => 'Zambi',
'ZW' => 'Zimbabwe',
);

==> MediaWikiLanguageExtensionBundle-2013.05.tar.bz2: extensions/cldr/CldrNames/CldrNamesLn.php <==
<?php

$languageNames = array(
'af' => 'afrikansi',
'ak' => 'akan',
'am' => 'liamariki',
'ar' => 'lialabo',
'be' => 'libyelorisí',
'bg' => 'libiligali',
'bn' => 'libengali',
'cs' => 'litshekɛ',
'de' => 'lialemá',
'de-at' => 'lialémani ya Otrish',
'de-ch' => 'lialémani ya Swisi',
'el' => 'ligeleki',
'en' => 'lingɛlɛ́sa',
'en-ca' => 'lingɛlɛ́sa ya Kanadá',
'en-gb' => 'lingɛlɛ́sa ya Ingɛlɛ́tɛlɛ',
'es' => 'lisipanye',
'es-419' => 'lispanyoli ya Ameríka Latína',
'es-es' => 'lispanyoli ya Erópa',
'fa' => 'lipelésanɛ',
'fr' => 'lifalansɛ́',
'fr-ca' => 'lifalansɛ́ ya Kanadá',
'fr-ch' => 'lifalansɛ́ ya Swisi',
'gsw' => 'lialemaniki',
'ha' => 'hausa',
'he' => 'liébeleo',
'hi' => 'lihindi',
'hu' => 'liongili',
'id' => 'lindonezi',
'ig' => 'igbo',
'it' => 'litaliano',
'ja' => 'lizapɔ',
'jv' => 'lizava',
'kg' => 'kikɔ́ngɔ',
'km' => 'likambodza',
'ko' => 'likoreya',
'la' => 'latina',
'ln' => 'lingála',
'lu' => 'kiluba',
'lua' => 'ciluba',
'ms' => 'limalezi',
'my' => 'libilimá',
'ne' => 'linepalɛ',
'nl' => 'lifalamá',
'pa' => 'lipendzabi',
'pl' => 'lipolonɛ',
'pt' => 'lipulutugɛ́si',
'pt-br' => 'lipulutugɛ́si ya Brazil',
'pt-pt' => 'lipulutugɛ́si ya Erópa',
'rm' => 'liromansh',
'ro' => 'liromani',
'ru' => 'lirisí',
'rw' => 'kinyarwanda',
'so' => 'lisomali',
'sv' => 'lisuwedɛ',
'sw' => 'kiswahíli',
'ta' => 'litamuli',
'th' => 'litaye',
'tr' => 'litiliki',
'uk' => 'likrɛni',
'ur' => 'liurdu',
'vi' => 'liviyetinámi',
'yo' => 'yoruba',
'zh' => 'lisinwa',
'zu' => 'zulu',
);

$currencyNames = array(
'AED' => 'Dirihamɛ ya Lémila alabo',
'AOA' => 'Kwanza ya Angóla',
'ARS' => 'Peso y\'Argentina',
'AUD' => 'Dolarɛ ya Ositali',
'BHD' => 'Dinarɛ ya Bahrɛnɛ',
'BIF' => 'Falánga ya Burundi',
'BOB' => 'Boliviano',
'BRL' => 'Real ya Brazil',
'BWP' => 'Pula ya Botswana',
'CAD' => 'Dolarɛ ya Kanadá',
'CDF' => 'Falánga ya Kongó',
'CHF' => 'Falánga ya Swisɛ',
'CLP' => 'Peso ya Shili',
'CNY' => 'Yuanɛ Renminbi ya Sinɛ',
'COP' => 'Peso ya Kolombi',
'CRC' => 'Colon ya Kosta Rika',
'CUP' => 'Peso ya Kuba',
'CVE' => 'Esikudo ya Kapevɛrɛ',
'CZK' => 'Motolé Sheki',
'DJF' => 'Falánga ya Dzibuti',
'DKK' => 'Motolé ya Danemark',
'DOP' => 'Peso Dominikani',
'DZD' => 'Dinarɛ ya Alizeri',
'EGP' => 'Paunɛ ya Ezípitɛ',
'ERN' => 'Nakfa ya Elitlɛ',
'ETB' => 'Birɛ ya Etsiópi',
'EUR' => 'Ɛlɔ́',
'GBP' => 'Paunɛ ya Angɛlɛtɛ́lɛ',
'GHC' => 'Sedi ya Gana',
'GHS' => 'Cedi',
'GMD' => 'Dalasi ya Gambi',
'GNF' => 'Falánga ya Gine',
'GNS' => 'Falánga ya Ginɛ',
'HTG' => 'Gurde',
'INR' => 'Rupi ya Índɛ',
'ISK' => 'Motolé ya Islandi',
'JPY' => 'Yeni ya Zapɔ',
'KES' => 'Shilingɛ ya Kenya',
'KMF' => 'Falánga ya Komoro',
'LRD' => 'Dolarɛ ya Liberya',
'LSL' => 'Loti ya Lesóto',
'LTL' => 'Litas ya Litwani',
'LVL' => 'Lats ya Letoni',
'LYD' => 'Dinarɛ ya Libí',
'MAD' => 'Dirihame ya Marokɛ',
'MGA' => 'Falánga ya Madagasikarɛ',
'MRO' => 'Ugwiya ya Moritani',
'MUR' => 'Rupi ya Morisi',
'MWK' => 'Kwasha ya Malawi',
'MXN' => 'Peso ya Mexiko',
'MZM' => 'Metikali ya Mozambiki',
'NAD' => 'Dolarɛ ya Namibi',
'NGN' => 'Naira ya Nizerya',
'NOK' => 'Motolé ya Norvej',
'PAB' => 'Balboa',
'PEN' => 'Sol Sika',
'PYG' => 'Guarani',
'RWF' => 'Falánga ya Rwanda',
'SAR' => 'Riyalɛ ya Alabi Sawuditɛ',
'SCR' => 'Rupi ya Sɛshɛlɛ',
'SDG' => 'Dinarɛ ya Sudá',
'SDP' => 'Paunɛ ya Sudá',
'SEK' => 'Motolé ya Swédi',
'SHP' => 'Paunɛ ya Sántu elena',
'SLL' => 'Leonɛ',
'SOS' => 'Shilingɛ ya Somali',
'STD' => 'Dobra ya Sao Tomé mpé Presipe',
'SZL' => 'Lilangeni',
'TND' => 'Dinarɛ ya Tinizi',
'TZS' => 'Shilingɛ ya Tanzani',
'UGX' => 'Shilingɛ ya Uganda',
'USD' => 'Dolarɛ ya Ameriki',
'XAF' => 'Falánga CFA BEAC',
'XOF' => 'Falánga CFA BCEAO',
'ZAR' => 'Randɛ ya Afríka Súdi',
'ZMK' => 'Kwasha ya Zambi (1968-2012)',
'ZMW' => 'Kwasha ya Zambi',
'ZWD' => 'Dolarɛ ya Zimbabwɛ',
);

$countryNames = array(
'AC' => 'Esenga ya Mbuta o likoló',
'AD' => 'Andorɛ',
'AE' => 'Lɛmila alabo',
'AF' => 'Afiganisitá',
'AG' => 'Antiga mpé Barbuda',
'AI' => 'Angiyɛ',
'AL' => 'Alibani',
'AM' => 'Amɛni',
'AN' => 'Antiyɛ ya Olandɛ',
'AO' => 'Angóla',
'AR' => 'Arizantinɛ',
'AS' => 'Samoa ya Ameriki',
'AT' => 'Otilisi',
'AU' => 'Ositáli',
'AW' => 'Aruba',
'AX' => 'Bisanga Ɛland',
'AZ' => 'Azɛlɛbaizá',
'BA' => 'Bosini mpé Hezegovine',
'BB' => 'Barɛbadɛ',
'BD' => 'Bengalidɛsi',
'BE' => 'Beleziki',
'BF' => 'Bukina Faso',
'BG' => 'Biligari',
'BH' => 'Bahrɛnɛ',
'BI' => 'Burundi',
'BJ' => 'Benɛ',
'BM' => 'Bermuda',
'BN' => 'Brineyi',
'BO' => 'Bolivi',
'BR' => 'Brezílɛ',
'BS' => 'Bahamasɛ',
'BT' => 'Butáni',
'BV' => 'Esenga Buvé',
'BW' => 'Botswana',
'BY' => 'Byelorisi',
'BZ' => 'Belizɛ',
'CA' => 'Kanada',
'CC' => 'Bisanga Kokos',
'CD' => 'Repibiki demokratiki ya Kongó',
'CF' => 'Repibiki ya Afríka ya Káti',
'CG' => 'Kongo',
'CH' => 'Swisɛ',
'CI' => 'Kotídivualɛ',
'CK' => 'Bisanga bya Kookɛ',
'CL' => 'Síli',
'CM' => 'Kamɛrune',
'CN' => 'Sinɛ',
'CO' => 'Kolombi',
'CR' => 'Kositarika',
'CU' => 'Kiba',
'CV' => 'Bisanga bya Kapevɛrɛ',
'CX' => 'Esenga ya Mbótama',
'CY' => 'Sípɛlɛ',
'CZ' => 'Repibiki Tsekɛ',
'DE' => 'Alemani',
'DJ' => 'Dzibuti',
'DK' => 'Danɛmarike',
'DM' => 'Domínike',
'DO' => 'Repibiki ya Domínikɛ',
'DZ' => 'Alizɛri',
'EA' => 'Zewta mpé Melílla',
'EC' => 'Ekwatɛ́lɛ',
'EE' => 'Esitoni',
'EG' => 'Ezípite',
'EH' => 'Sahara ya Limbɛ',
'ER' => 'Elitelɛ',
'ES' => 'Esipanye',
'ET' => 'Etsíopi',
'EU' => 'Lisangá ya Erópa',
'FI' => 'Filandɛ',
'FJ' => 'Fidzi',
'FK' => 'Bisanga bya Maluni',
'FM' => 'Mikronezi',
'FO' => 'Bisanga ya Fɛróa',
'FR' => 'Falánsɛ',
'GA' => 'Gabɔ',
'GB' => 'Angɛlɛtɛ́lɛ',
'GD' => 'Gelenadɛ',
'GE' => 'Zorzi',
'GF' => 'Giyanɛ ya Falánsɛ',
'GH' => 'Gana',
'GI' => 'Zibatalɛ',
'GL' => 'Gowelande',
'GM' => 'Gambi',
'GN' => 'Ginɛ',
'GP' => 'Gwadɛlupɛ',
'GQ' => 'Ginɛ́kwatɛ́lɛ',
'GR' => 'Geleki',
'GT' => 'Gwatémala',
'GU' => 'Gwamɛ',
'GW' => 'Ginɛbisau',
'GY' => 'Giyane',
'HK' => 'Hong Kong',
'HN' => 'Ondurasɛ',
'HR' => 'Krowasi',
'HT' => 'Ayiti',
'HU' => 'Ongili',
'IC' => 'Bisanga bya Kanári',
'ID' => 'Indonezi',
'IE' => 'Irelandɛ',
'IL' => 'Isirayelɛ',
'IM' => 'Esanga ya Man',
'IN' => 'Índɛ',
'IO' => 'Mabelé ya Angɛlɛtɛ́lɛ na mbú ya Indiya',
'IQ' => 'Iraki',
'IR' => 'Irâ',
'IS' => 'Isilandɛ',
'IT' => 'Itali',
'JM' => 'Zamaiki',
'JO' => 'Zɔdani',
'JP' => 'Zapɔ',
'KE' => 'Kenya',
'KG' => 'Kigizisitá',
'KH' => 'Kambodza',
'KI' => 'Kiribati',
'KM' => 'Komorɛ',
'KN' => 'Sántu krístofe mpé Nevɛ̀s',
'KP' => 'Korɛ ya nɔ́rdi',
'KR' => 'Korɛ ya súdi',
'KW' => 'Koweti',
'KY' => 'Bisanga bya Kayíma',
'KZ' => 'Kazakisitá',
'LA' => 'Lawosi',
'LB' => 'Libá',
'LC' => 'Sántu lisi',
'LI' => 'Lishɛteni',
'LK' => 'Sirilanka',
'LR' => 'Libériya',
'LS' => 'Lesoto',
'LT' => 'Litwani',
'LU' => 'Likisambulu',
'LV' => 'Letoni',
'LY' => 'Libí',
'MA' => 'Marokɛ',
'MC' => 'Monako',
'MD' => 'Molidavi',
'MG' => 'Madagasikari',
'MH' => 'Bisanga bya Marishalɛ',
'MK' => 'Masedwanɛ',
'ML' => 'Malí',
'MN' => 'Mongolí',
'MO' => 'Makau',
'MP' => 'Bisanga bya Marianɛ ya nɔ́rdi',
'MQ' => 'Martiniki',
'MR' => 'Moritani',
'MS' => 'Mɔsera',
'MT' => 'Malitɛ',
'MU' => 'Morisɛ',
'MV' => 'Madívɛ',
'MW' => 'Malawi',
'MX' => 'Meksike',
'MY' => 'Malezi',
'MZ' => 'Mozambíki',
'NA' => 'Namibi',
'NC' => 'Kaledoni ya sika',
'NE' => 'Nizɛrɛ',
'NF' => 'Esanga Norfokɛ',
'NG' => 'Nizerya',
'NI' => 'Nikaragwa',
'NL' => 'Olandɛ',
'NO' => 'Norivezɛ',
'NP' => 'Nepálɛ',
'NR' => 'Nauru',
'NU' => 'Nyué',
'NZ' => 'Zelandɛ ya sika',
'OM' => 'Ománɛ',
'PA' => 'Panama',
'PE' => 'Péru',
'PF' => 'Polinezi ya Falánsɛ',
'PG' => 'Papwazi Ginɛ ya sika',
'PH' => 'Filipinɛ',
'PK' => 'Pakisitá',
'PL' => 'Poloni',
'PM' => 'Sántu pététo mpé Mikelɔ',
'PN' => 'Pikairni',
'PR' => 'Pɔtoriko',
'PS' => 'Palɛsine',
'PT' => 'Putúlugɛsi',
'PW' => 'Palau',
'PY' => 'Palagwei',
'QA' => 'Katari',
'RE' => 'Lenyo',
'RO' => 'Romani',
'RU' => 'Risí',
'RW' => 'Rwanda',
'SA' => 'Alabi Sawuditɛ',
'SB' => 'Bisanga Solomɔ',
'SC' => 'Sɛshɛlɛ',
'SD' => 'Sudá',
'SE' => 'Swédɛ',
'SG' => 'Singapurɛ',
'SH' => 'Sántu eleni',
'SI' => 'Siloveni',
'SJ' => 'Svalbard mpé Jan Mayen',
'SK' => 'Silovaki',
'SL' => 'Siera Leonɛ',
'SM' => 'Sántu Marinɛ',
'SN' => 'Senegalɛ',
'SO' => 'Somali',
'SR' => 'Surinamɛ',
'SS' => 'Sudani ya Sidi',
'ST' => 'Sao Tomé mpé Presipɛ',
'SV' => 'Savadɔrɛ',
'SY' => 'Sirí',
'SZ' => 'Swazilandi',
'TC' => 'Bisanga bya Turki mpé Kaiko',
'TD' => 'Tsádi',
'TG' => 'Togo',
'TH' => 'Tailandɛ',
'TJ' => 'Tazikisitá',
'TK' => 'Tokelau',
'TL' => 'Timorɛ ya Moniɛlɛ',
'TM' => 'Tikɛménisitá',
'TN' => 'Tinizi',
'TO' => 'Tonga',
'TR' => 'Tiliki',
'TT' => 'Tinidadɛ mpé Tobago',
'TV' => 'Tuvalu',
'TW' => 'Taiwanin',
'TZ' => 'Tanzani',
'UA' => 'Ikrɛni',
'UG' => 'Uganda',
'US' => 'Ameriki',
'UY' => 'Irigwei',
'UZ' => 'Uzibɛkisitá',
'VA' => 'Vatiká',
'VC' => 'Sántu vesá mpé Gelenadinɛ',
'VE' => 'Venézuela',
'VG' => 'Bisanga bya Vierzi ya Angɛlɛtɛ́lɛ',
'VI' => 'Bisanga bya Vierzi ya Ameriki',
'VN' => 'Viyetinamɛ',
'VU' => 'Vanuatu',
'WF' => 'Walisɛ mpé Futuna',
'WS' => 'Samoa',
'YE' => 'Yemɛnɛ',
'YT' => 'Mayotɛ',
'ZA' => 'Afríka ya Súdi',
'ZM' => 'Zambi',
'ZW' => 'Zimbabwe',
);
